Method: HelloSign::Resource::BaseResource#method_missing
- Defined in:
- lib/hello_sign/resource/base_resource.rb
#method_missing(method) ⇒ Object
Magic method, give class dynamic methods based on hash keys.
If initialized hash has a key which matches the method name, return value of that key.
Otherwise, return nil
47 48 49 |
# File 'lib/hello_sign/resource/base_resource.rb', line 47 def method_missing(method) @data.key?(method.to_s) ? @data[method.to_s] : nil end |