Method: HelloSign::Resource::Template#initialize

Defined in:
lib/hello_sign/resource/template.rb

#initialize(hash, key = 'template') ⇒ HelloSign::Resource:Team

create a new Template from a hash. If a key is defined then template data will be the value of hash, otherwise the hash itself

Parameters:

  • hash (Hash)

    template’s data

  • key (String) (defaults to: 'template')

    (template) key of the hash, point to where template data is. If nil then the hash itself



43
44
45
# File 'lib/hello_sign/resource/template.rb', line 43

def initialize(hash, key='template')
  super
end